#####################################################################################################################################
### This is the script we used to run DADI for simulations. This script needs dependency on DADI_Simulation_demographic_models.py
### We used project size [100,100] and pts_l = [100,200,300].
#####################################################################################################################################

#!/urs/bin/python
import numpy
import scipy
from numpy import array
import os
import sys
import dadi
import DADI_Simulation_demographic_models


def dadi_estimation(inputfile, demographic, polarized, migration):
  dd = dadi.Misc.make_data_dict(inputfile)
  print "Done: read date from input file!"
  data = dadi.Spectrum.from_data_dict(dd, pop_ids=['Pop1','Pop2'], projections=[100,100], polarized=polarized)
  ns = data.sample_sizes
  print "The projections = [100,100]"
  pts_l = [100,200,300]
  print "pts_l = [100,200,300]"

  # simple isolation migration model
  if demographic == "Isolation-Migration" : 
    func  = dadi.Demographics2D.split_mig
    params = array([1.0,1.0,0.04,1])
    upper_bound = [100,100,3,20]
    lower_bound = [1e-2,1e-2,0,0]
    fixed_params = [None, None, None, 0.0]
    print "The model is Isolation-Migration model"
    print "The parameters are : (nu1, nu2, T, m)"
    print "The initial parameters are: ", params
  
 
  # two pop bottleneck model
  if demographic == 'Twopop-Bottleneck-Model': 
    pts_l = [100,200,300]
    func = demographic_models.prior_twopop_bottleneck_mig
    params = array([0.07, 1.0, 0.07, 1.0, 1.0, 2, 0.3, 0.1])
    upper_bound = [100, 100, 100, 100, 100, 10,3,3]
    lower_bound = [1e-2,1e-2,1e-2,1e-2, 1e-2, 0, 0,0]
    fixed_params = [None, None, None, None, 1.0, 0.0, None, None]
    print "The model is two pop bottleneck model"
    print "The parameters are: (nu1B, nu1F,nu2B,nu2F,nuA, m,Tp,T)"
    print "The initial parameters are: ", params 
  
  # bottleneck-nonbottleneck model
  if demographic == 'Bottleneck-NonBottleneck': 
    func =  demographic_models.prior_bottleneck_nonbottleneck_mig
    params = array([1.0, 0.1, 1.0, 1.0, 1.0, 2.0, 0.3, 0.05, 0.05])
    upper_bound = [100, 100, 100, 100, 100, 10, 3, 3, 3]
    lower_bound = [1e-2, 1e-2, 1e-2, 1e-2, 1e-2,  0, 0, 0, 0]
    fixed_params = [None, None, None, None, 1.0, 0.0,  None, None, None]
    print "The model is bottleneck-nonbottleneck model"
    print "The parameters are: (nu1S, nu1B, nu1F, nu2F, nuA, m, Tp, T1, T2)"
    print "The initial parameters are: ", params

  # Makde the extrapolating version of our demographic model function.
  func_ex = dadi.Numerics.make_extrap_log_func(func)
  model = func_ex(params, ns, pts_l)
  ll_model = dadi.Inference.ll_multinom(model, data)
  print 'Model log-likelihood:', ll_model
  theta = dadi.Inference.optimal_sfs_scaling(model, data)
  print 'Model estimated theta = ', theta
  p0 = dadi.Misc.perturb_params(params, fold=1, upper_bound=upper_bound)
  if migration == 'True':
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, lower_bound=lower_bound, upper_bound=upper_bound, verbose=len(params),maxiter=5000)
  else:
    popt = dadi.Inference.optimize_log(p0, data, func_ex, pts_l, fixed_params = fixed_params,  lower_bound=lower_bound, upper_bound=upper_bound, verbose=len(params),maxiter=5000)
  print "The optimized parameters are: ", popt
  



def main(argv):
  if len(argv)<5:
    print "Model to run with DADI_Simulation_demographic_models.py" 
    print "Usage: DADI-Simulation.py <input file><demographic(Isolation-Migration/Bottleneck-NonBottleneck/Twopop-Bottleneck-Model)><polarized(True/False)><migration(True/False)>"
    exit(2)
  inputfile = argv[1]
  demographic = argv[2]
  polarized = argv[3]
  migration = argv[4]
  dadi_estimation(inputfile, demographic, polarized, migration)
  
if __name__=='__main__':
  main(sys.argv)

