##########################################################################################################################
### This script takes the summary of rLD from two populations to calculate T-LD and T-FST.
### Usage: Rscript T-LD-FST-result.R <summary_rLD.txt> <pop1_pop2.weir.fst> <substitution rate>
##########################################################################################################################

#!/bin/Rscript
args <- commandArgs(TRUE)

LDfile = args[1]
FSTfile = args[2]
u=as.numeric(args[3])

nsample = c(500,500)

data=matrix(scan(LDfile,what=""),byrow=T,nc=51)
rLD2_pop1=as.numeric(data[data[,1]=="sum_rLD2_pop1",-1])/as.numeric(data[data[,1]=="number_of_pairs",-1]) - 1/nsample[1]
rLD2_pop2=as.numeric(data[data[,1]=="sum_rLD2_pop2",-1])/as.numeric(data[data[,1]=="number_of_pairs",-1]) - 1/nsample[2]
c=(as.numeric(data[data[,1]=="lowerBoundary",-1])+as.numeric(data[data[,1]=="higherBoundary",-1]))/200
tgen=1/(2*c)
t=tgen*25  
Ne_pop1=1/(4*c)*(1/rLD2_pop1-2) 
Ne_pop2=1/(4*c)*(1/rLD2_pop2-2) 
bins=which(c<0.001)[-1]
FST=matrix(scan(FSTfile,what=""),byrow=T,nc=3)[-1,]
FST=mean(as.numeric(FST[,3])) 
Ne=2/(1/mean(Ne_pop1[bins])+1/mean(Ne_pop2[bins]))
T_FSTgen=FST*2*Ne
T_FST=T_FSTgen*25

barX=as.numeric(data[data[,1]=="sum_rLD_pop1",-1])/as.numeric(data[data[,1]=="number_of_pairs",-1])
barY=as.numeric(data[data[,1]=="sum_rLD_pop2",-1])/as.numeric(data[data[,1]=="number_of_pairs",-1])
covXY=1/(as.numeric(data[data[,1]=="number_of_pairs",-1])-1)*as.numeric(data[data[,1]=="sum_product",-1])-(as.numeric(data[data[,1]=="number_of_pairs",-1]))/(as.numeric(data[data[,1]=="number_of_pairs",-1])-1)*barX*barY
sigmaX2=1/(as.numeric(data[data[,1]=="number_of_pairs",-1])-1)*(as.numeric(data[data[,1]=="sum_rLD2_pop1",-1]))-as.numeric(data[data[,1]=="number_of_pairs",-1])/(as.numeric(data[data[,1]=="number_of_pairs",-1])-1)*barX^2
sigmaY2=1/(as.numeric(data[data[,1]=="number_of_pairs",-1])-1)*(as.numeric(data[data[,1]=="sum_rLD2_pop2",-1]))-as.numeric(data[data[,1]=="number_of_pairs",-1])/(as.numeric(data[data[,1]=="number_of_pairs",-1])-1)*barY^2
sigmaX2=sigmaX2-1/nsample[1]
sigmaY2=sigmaY2-1/nsample[2]
rpop=covXY/sqrt(sigmaX2*sigmaY2)
lnrpop=log(rpop[bins])

bins=bins[which(!is.na(lnrpop))]
lnrpop=lnrpop[which(!is.na(lnrpop))]
T_LDgen=cor(lnrpop,c[bins])*sd(lnrpop)/sd(c[bins])/(-2)
T_LD=T_LDgen*25 

print(round(c(T_LD,T_FST),3))
