###################################################################################
### This is a script help calculate the correlation, mean and variance of rLD 
### within each genetic distance bin. 
### The input format should be four colunms with header line and tab-delimited (the 
### fourth column is the product of r_LD_pop1 and r_LD_pop2 at this pair of SNPs):
### genetic.distance(cM)    r_LD_pop1       r_LD_pop2       (r_LD_pop1)(r_LD_pop2)
### The output file is used by T-LD-FST-result.R to calculate T-LD and T-FST.
###################################################################################

#!urs/bin/perl
#use warnings;
#use strict;

if(!defined($ARGV[0])){
        die "$0:<pop1.pop2.chr.rLD.txt file>\n";
}

open(LD,"$ARGV[0]") or die "Cannot open pop1.pop2.chr.rLD.txt file:$!\n";

my %fields=();
my $header=1;
my @lowerBoundary;
my @higherBoundary;
my @sum_X;
my @sum_X2;
my @sum_Y;
my @sum_Y2;
my @sum_XY;
my @nbin;
my $line=0;
for(my $i=0;$i<50;$i++){
        $sum_X[$i]=0;
	$sum_X2[$i]=0;
        $sum_Y[$i]=0; 
	$sum_Y2[$i]=0;
        $sum_XY[$i]=0;
	$nbin[$i]=0;
        $lowerBoundary[$i]=sprintf("%.4f",0.0+$i*0.005);
        $higherBoundary[$i]=sprintf("%.4f",0.005+$i*0.005);
}

while(<LD>){
	chomp;
        my @cat=split(/\t/,$_);
        if( $header==1 ){
                for(my $i=0; $i<=$#cat; $i++){$fields{$cat[$i]}=$i;}    
                $header=0;
                next;
        }
        if($header==0){
                my $bin=-1;
                for($i=0;$i<50;$i++){if($cat[$fields{"genetic\.distance\(cM\)"}] <= $higherBoundary[$i] && $cat[$fields{"genetic\.distance\(cM\)"}] > $lowerBoundary[$i]){$bin=$i;last;}}
		if($bin==(-1)){print "Warning:\t$cat[0]\t$cat[1]\n";} 
                else{ 
                #print "$cat[2] \t $lowerBoundary[$bin]\t$higherBoundary[$bin]\n";
                $sum_X[$bin]+=($cat[$fields{"r_LD_pop1"}]);
		$sum_X2[$bin]+=($cat[$fields{"r_LD_pop1"}]*$cat[$fields{"r_LD_pop1"}]);
                $sum_Y[$bin]+=($cat[$fields{"r_LD_pop2"}]);
		$sum_Y2[$bin]+=($cat[$fields{"r_LD_pop2"}]*$cat[$fields{"r_LD_pop2"}]);
		$sum_XY[$bin]+=($cat[$fields{"\(r_LD_pop1\)\(r_LD_pop2\)"}]);
                $nbin[$bin]++;}
	}
	#$line++;
	#if($line==10000){last;}
}
close LD;         

print "bin";
for(my $i=0;$i<50;$i++){print "\t$i";}
print "\n";

print "lowerBoundary";
for(my $i=0;$i<50;$i++){print "\t$lowerBoundary[$i]";}
print "\n";

print "higherBoundary";
for(my $i=0;$i<50;$i++){print "\t$higherBoundary[$i]";}
print "\n";

print "sum_rLD_pop1";
for(my $i=0;$i<50;$i++){$sum_X[$i]=sprintf("%.5f",$sum_X[$i]); print "\t$sum_X[$i]";}
print "\n";

print "sum_rLD_pop2";
for(my $i=0;$i<50;$i++){$sum_Y[$i]=sprintf("%.5f",$sum_Y[$i]); print "\t$sum_Y[$i]";}
print "\n";

print "sum_rLD2_pop1";
for(my $i=0;$i<50;$i++){$sum_X2[$i]=sprintf("%.5f",$sum_X2[$i]); print "\t$sum_X2[$i]";}
print "\n";

print "sum_rLD2_pop2";
for(my $i=0;$i<50;$i++){$sum_Y2[$i]=sprintf("%.5f",$sum_Y2[$i]); print "\t$sum_Y2[$i]";}
print "\n";

print "sum_product";
for(my $i=0;$i<50;$i++){$sum_XY[$i]=sprintf("%.5f",$sum_XY[$i]); print "\t$sum_XY[$i]";}
print "\n";

print "number_of_pairs";
for(my $i=0;$i<50;$i++){print "\t$nbin[$i]";}
print "\n";




